@@ -65,7 +65,7 @@ class UserCheckStateDTO:
         return {
             id: cls(
                 user_id=id,
-                checks=items,
+                checks={check.reason: check for check in items},
                 is_reviewed=all(check.is_reviewed for check in items),
                 is_passed=all(check.is_passed for check in items),
             )
